@@ -1,12 +1,15 @@
 package Data::ModeMerge::Mode::ADD;
 BEGIN {
-  $Data::ModeMerge::Mode::ADD::VERSION = '0.25';
+  $Data::ModeMerge::Mode::ADD::VERSION = '0.26';
 }
 # ABSTRACT: Handler for Data::ModeMerge ADD merge mode
 
 
 use 5.010;
-use Any::Moose;
+use strict;
+use warnings;
+
+use Moo;
 extends 'Data::ModeMerge::Mode::NORMAL';
 
 sub name { 'ADD' }
@@ -63,8 +66,6 @@ sub merge_HASH_ARRAY {
     return;
 }
 
-__PACKAGE__->meta->make_immutable;
-no Any::Moose;
 1;
 
 __END__
@@ -76,7 +77,7 @@ Data::ModeMerge::Mode::ADD - Handler for Data::ModeMerge ADD merge mode
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -94,7 +95,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Steven Haryanto.
+This software is copyright (c) 2011 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
